@@ -5,7 +5,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Plack::Util;
 use Mojo::Message::Request;
 use Mojo::Message::Response;
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 use Scalar::Util 'weaken';
     
     ### ---
@@ -53,20 +53,18 @@ use Scalar::Util 'weaken';
         $app->hook('around_dispatch' => sub {
             my ($next, $c) = @_;
             
-            if ($c->tx->req->error) {
-                $next->();
-            } else {
-                my $plack_env = mojo_req_to_psgi_env($c->req);
-                $plack_env->{'mojo.c'} = $c;
-                $plack_env->{'mojo.inside_app'} = $next;
-                $plack_env->{'psgi.errors'} =
-                    Mojolicious::Plugin::PlackMiddleware::_EH->new(sub {
-                        $c->app->log->debug(shift);
-                    });
-                
-                $c->tx->res(psgi_res_to_mojo_res($plack_app->($plack_env)));
-                $c->rendered if (! $plack_env->{'mojo.routed'});
-            }
+            return $next->() if ($c->tx->req->error);
+            
+            my $plack_env = mojo_req_to_psgi_env($c->req);
+            $plack_env->{'mojo.c'} = $c;
+            $plack_env->{'mojo.inside_app'} = $next;
+            $plack_env->{'psgi.errors'} =
+                Mojolicious::Plugin::PlackMiddleware::_EH->new(sub {
+                    $c->app->log->debug(shift);
+                });
+            
+            $c->tx->res(psgi_res_to_mojo_res($plack_app->($plack_env)));
+            $c->rendered if (! $plack_env->{'mojo.routed'});
         });
     }
     
@@ -83,6 +81,8 @@ use Scalar::Util 'weaken';
         my $env = shift;
         my $req = Mojo::Message::Request->new->parse($env);
         
+        $req->reverse_proxy($env->{MOJO_REVERSE_PROXY});
+        
         # Request body
         my $len = $env->{CONTENT_LENGTH};
         while (!$req->is_finished) {
@@ -108,12 +108,15 @@ use Scalar::Util 'weaken';
         my $body =
         Mojolicious::Plugin::PlackMiddleware::_PSGIInput->new($mojo_req->build_body);
         
-        my %headers = %{$mojo_req->headers->to_hash};
-        for my $key (keys %headers) {
-           my $value = $headers{$key};
-           delete $headers{$key};
-           $key =~ s{-}{_}g;
-           $headers{'HTTP_'. uc $key} = $value;
+        my %headers_org = %{$mojo_req->headers->to_hash};
+        my %headers;
+        for my $key (keys %headers_org) {
+            
+            my $value = $headers_org{$key};
+            $key =~ s{-}{_}g;
+            $key = uc $key;
+            $key = "HTTP_$key" if ($key !~ /^(?:CONTENT_LENGTH|CONTENT_TYPE)$/);
+            $headers{$key} = $value;
         }
         
         return {
@@ -167,9 +170,7 @@ use Scalar::Util 'weaken';
         my $status = $mojo_res->code;
         my $headers = $mojo_res->content->headers;
         my @headers;
-        for my $name (@{$headers->names}) {
-            push @headers, $name => $headers->header($name);
-        }
+        push @headers, $_ => $headers->header($_) for (@{$headers->names});
         my @body;
         my $offset = 0;
         
