@@ -25,8 +25,8 @@ plugin plack_middleware => [];
 get '/' => 'index';
 
 get '/echo' => sub {
-  my $self = shift;
-  $self->render(text => 'echo: ' . ($self->stash('message') || 'nothing!'));
+  my $c = shift;
+  $c->render(text => 'echo: ' . ($c->stash('message') || 'nothing!'));
 };
 
 get '/stream' => sub {
@@ -38,15 +38,15 @@ get '/stream' => sub {
 };
 
 get '/url/☃' => sub {
-  my $self  = shift;
-  my $route = $self->url_for;
-  my $rel   = $self->url_for('/☃/stream');
-  $self->render(text => "$route -> $rel!");
+  my $c     = shift;
+  my $route = $c->url_for({format => 'json'});
+  my $rel   = $c->url_for('/☃/stream');
+  $c->render(text => "$route -> $rel!");
 };
 
 get '/host' => (message => 'it works!') => sub {
-  my $self = shift;
-  $self->render(text => $self->url_for->base->host);
+  my $c = shift;
+  $c->render(text => $c->url_for->base->host);
 };
 
 get '/one' => sub { shift->render(text => 'One') };
@@ -55,6 +55,16 @@ get '/one/two' => {text => 'Two'};
 
 get '/template/:template';
 
+websocket '/url_for' => sub {
+  my $c = shift;
+  $c->on(
+    message => sub {
+      my ($c, $msg) = @_;
+      $c->send($c->url_for($msg)->to_abs);
+    }
+  );
+} => 'ws_test';
+
 app->start;
 __DATA__
 
