@@ -17,14 +17,11 @@ sub startup {
   push @{$self->renderer->classes}, 'SingleFileTestApp::Foo';
   push @{$self->static->classes},   'SingleFileTestApp::Foo';
 
-  # Allow redispatching controller
-  push @{$self->routes->base_classes}, 'Mojo::Base';
-
   # Helper route
   $self->routes->route('/helper')->to(
     cb => sub {
-      my $self = shift;
-      $self->render(text => $self->some_plugin);
+      my $c = shift;
+      $c->render(text => $c->some_plugin);
     }
   );
 
@@ -33,7 +30,7 @@ sub startup {
 }
 
 package SingleFileTestApp::Redispatch;
-use Mojo::Base -base;
+use Mojo::Base 'Mojo';
 
 sub handler {
   my ($self, $c) = @_;
@@ -64,7 +61,7 @@ sub data_template { shift->render('index') }
 
 sub data_template2 { shift->stash(template => 'too') }
 
-sub data_static { shift->render_static('singlefiletestapp/foo.txt') }
+sub data_static { shift->reply->static('singlefiletestapp/foo.txt') }
 
 sub index {
   shift->stash(template => 'WithGreenLayout', msg => 'works great!');
